==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebToggleViewEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebToggleViewEventArgsDetailDescriptionMetadata } from "./WebToggleViewEventArgsDetailDescriptionMetadata";
import { WebToggleViewEventArgsDescription } from "./WebToggleViewEventArgsDescription";
/**
 * @hidden
 */
var WebToggleViewEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebToggleViewEventArgsDescriptionMetadata, _super);
    function WebToggleViewEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebToggleViewEventArgsDescriptionMetadata.b = function (a) {
        if (WebToggleViewEventArgsDescriptionMetadata.a == null) {
            WebToggleViewEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebToggleViewEventArgsDescriptionMetadata.c(WebToggleViewEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebToggleViewEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebToggleViewEventArgsDescriptionMetadata.a);
        WebToggleViewEventArgsDetailDescriptionMetadata.d(a);
    };
    WebToggleViewEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ToggleViewEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("Detail", "ExportedType:WebToggleViewEventArgsDetail");
    };
    WebToggleViewEventArgsDescriptionMetadata.d = function (a) {
        WebToggleViewEventArgsDescriptionMetadata.b(a);
        a.aa("WebToggleViewEventArgs", function () { return new WebToggleViewEventArgsDescription(); });
        a.z("WebToggleViewEventArgs", WebToggleViewEventArgsDescriptionMetadata.a);
    };
    WebToggleViewEventArgsDescriptionMetadata.$t = markType(WebToggleViewEventArgsDescriptionMetadata, 'WebToggleViewEventArgsDescriptionMetadata');
    WebToggleViewEventArgsDescriptionMetadata.a = null;
    return WebToggleViewEventArgsDescriptionMetadata;
}(Base));
export { WebToggleViewEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebToggleViewEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebToggleViewEventArgsDetailDescriptionMetadata } from "./WebToggleViewEventArgsDetailDescriptionMetadata";
import { WebToggleViewEventArgsDescription } from "./WebToggleViewEventArgsDescription";
/**
 * @hidden
 */
var WebToggleViewEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebToggleViewEventArgsDescriptionMetadata, _super);
    function WebToggleViewEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebToggleViewEventArgsDescriptionMetadata.b = function (a) {
        if (WebToggleViewEventArgsDescriptionMetadata.a == null) {
            WebToggleViewEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebToggleViewEventArgsDescriptionMetadata.c(WebToggleViewEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebToggleViewEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebToggleViewEventArgsDescriptionMetadata.a);
        WebToggleViewEventArgsDetailDescriptionMetadata.d(a);
    };
    WebToggleViewEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ToggleViewEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebToggleViewEventArgsDetail");
    };
    WebToggleViewEventArgsDescriptionMetadata.d = function (a) {
        WebToggleViewEventArgsDescriptionMetadata.b(a);
        a.ac("WebToggleViewEventArgs", function () { return new WebToggleViewEventArgsDescription(); });
        a.ab("WebToggleViewEventArgs", WebToggleViewEventArgsDescriptionMetadata.a);
    };
    WebToggleViewEventArgsDescriptionMetadata.$t = markType(WebToggleViewEventArgsDescriptionMetadata, 'WebToggleViewEventArgsDescriptionMetadata');
    WebToggleViewEventArgsDescriptionMetadata.a = null;
    return WebToggleViewEventArgsDescriptionMetadata;
}(Base));
export { WebToggleViewEventArgsDescriptionMetadata };
